==> openshift-model-machine-5.10.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/LastOperationFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class LastOperationFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<A>{
  public LastOperationFluentImpl() {
  }
  public LastOperationFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.LastOperation instance) {
    this.withDescription(instance.getDescription()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withState(instance.getState()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private java.lang.String lastUpdated;
  private java.lang.String state;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.String getLastUpdated() {
    return this.lastUpdated;
  }
  public A withLastUpdated(java.lang.String lastUpdated) {
    this.lastUpdated=lastUpdated; return (A) this;
  }
  public java.lang.Boolean hasLastUpdated() {
    return this.lastUpdated != null;
  }
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0) {
    return (A)withLastUpdated(new String(arg0));
  }
  public java.lang.String getState() {
    return this.state;
  }
  public A withState(java.lang.String state) {
    this.state=state; return (A) this;
  }
  public java.lang.Boolean hasState() {
    return this.state != null;
  }
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0) {
    return (A)withState(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LastOperationFluentImpl that = (LastOperationFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (lastUpdated != null ? !lastUpdated.equals(that.lastUpdated) :that.lastUpdated != null) return false;
    if (state != null ? !state.equals(that.state) :that.state != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  lastUpdated,  state,  type,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-machine-5.12.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/LastOperationFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class LastOperationFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<A>{
  public LastOperationFluentImpl() {
  }
  public LastOperationFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.LastOperation instance) {
    this.withDescription(instance.getDescription()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withState(instance.getState()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private java.lang.String lastUpdated;
  private java.lang.String state;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.String getLastUpdated() {
    return this.lastUpdated;
  }
  public A withLastUpdated(java.lang.String lastUpdated) {
    this.lastUpdated=lastUpdated; return (A) this;
  }
  public java.lang.Boolean hasLastUpdated() {
    return this.lastUpdated != null;
  }
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0) {
    return (A)withLastUpdated(new String(arg0));
  }
  public java.lang.String getState() {
    return this.state;
  }
  public A withState(java.lang.String state) {
    this.state=state; return (A) this;
  }
  public java.lang.Boolean hasState() {
    return this.state != null;
  }
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0) {
    return (A)withState(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LastOperationFluentImpl that = (LastOperationFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (lastUpdated != null ? !lastUpdated.equals(that.lastUpdated) :that.lastUpdated != null) return false;
    if (state != null ? !state.equals(that.state) :that.state != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  lastUpdated,  state,  type,  additionalProperties,  super.hashCode());
  }
  
}
